# -*- coding: utf-8 -*-
#
import pygmsh
import examples

import os
import tempfile
from importlib import import_module
import subprocess


def test_generator():
    for name in examples.__all__:
        test = import_module('examples.' + name)
        yield check_output, test


def check_output(test):
    pygmsh.generate_mesh(test.generate())
    return


if __name__ == '__main__':
    test_io()



# -*- coding: utf-8 -*-
#
__version__ = '2.4.0'
__author__ = 'Nico Schlömer'
__author_email__ = 'nico.schloemer@gmail.com'
__website__ = 'https://github.com/nschloe/pygmsh'

from pygmsh.geometry import Geometry
from pygmsh.helper import *

__all__ = [
        'geometry',
        'helper'
        ]



# -*- coding: utf-8 -*-
#
import os
from distutils.core import setup
import codecs

from pygmsh import __name__, __version__, __author__, __author_email__


def read(fname):
    try:
        content = codecs.open(
            os.path.join(os.path.dirname(__file__), fname),
            encoding='utf-8'
            ).read()
    except Exception:
        content = ''
    return content

setup(
    name=__name__,
    version=__version__,
    author=__author__,
    author_email=__author_email__,
    packages=['pygmsh'],
    description='Python frontend for Gmsh',
    long_description=read('README.rst'),
    url='https://github.com/nschloe/pygmsh',
    download_url='https://pypi.python.org/pypi/pygmsh',
    license='License :: OSI Approved :: MIT License',
    platforms='any',
    requires=[
        'numpy'
        ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Science/Research',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Mathematics'
        ]
    )
